@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Provide musical cadence chords
 
-our $VERSION = '0.0403';
+our $VERSION = '0.0404';
 
 use Moo;
 use Music::Chord::Note;
@@ -136,13 +136,15 @@ Music::Cadence - Provide musical cadence chords
 
 =head1 VERSION
 
-version 0.0403
+version 0.0404
 
 =head1 SYNOPSIS
 
   use Music::Cadence;
 
-  my $mc = Music::Cadence->new(
+  my $mc = Music::Cadence->new;
+
+  $mc = Music::Cadence->new(
     key    => 'C',
     scale  => 'major',
     octave => 4,
@@ -207,9 +209,9 @@ Create a new C<Music::Cadence> object.
 
 =head2 cadence
 
-  $chords = $mc->cadence;  # Use defaults
+  $chords = $mc->cadence;     # Use defaults
 
-  $chords = $mc->cadence(
+  $chords = $mc->cadence(     # Override defaults
     key       => $key,        # Default: C
     scale     => $scale,      # Default: major
     octave    => $octave,     # Default: 0
@@ -218,9 +220,8 @@ Create a new C<Music::Cadence> object.
     variation => $variation,  # Default: 1
   );
 
-Return an array reference of the chords of the cadence B<type> (and
-B<leading> chord when B<type> is C<half>) based on the given B<key>
-and B<scale> name.
+Return an array reference of the chords of the cadence B<type> based
+on the given B<key> and B<scale> name.
 
 The B<octave> is optional and if given, should be a number greater
 than or equal to zero.
